/**
 * Copyright (C) 2005-2011 by Rivello Multimedia Consulting (RMC)                     
 * info@RivelloMultimediaConsulting.com                                                  
 *                                                                      
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the      
 * "Software"), to deal in the Software without restriction, including  
 * without limitation the rights to use, copy, modify, merge, publish,  
 * distribute, sublicense, and#or sell copies of the Software, and to   
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:                                            
 *                                                                      
 * The above copyright notice and this permission notice shall be       
 * included in all copies or substantial portions of the Software.      
 *                                                                      
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,      
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF   
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR    
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.                                      
 */
// Marks the right margin of code *******************************************************************
package com.rmc.demos.frametagmetadatademo.display.preloaders
{
	import flash.events.Event;
	import com.rmc.demos.frametagmetadatademo.managers.PreloaderAssetManager;
  
	// --------------------------------------
	// Imports
	// --------------------------------------
	import flash.display.Sprite;
	import flash.text.AntiAliasType;
	import flash.text.TextField;
	import flash.text.TextFormat;


	// --------------------------------------
	// Metadata
	// --------------------------------------

	// --------------------------------------
	// Class
	// --------------------------------------
	/**
	 * <p>The <code>Preloader</code> shows %XX percent and a repeating animation,
	 * as the main application is loading.</p>
	 * 
	 * <p>AUTHOR  : Samuel Asher Rivello</p>
	 * <p>COMPANY : RivelloMultimediaConsulting.com</p>
	 * <p>EMAIL   : info@RivelloMultimediaConsulting.com</p>
	 * <p>CREATION DATE    : Apr 7, 2011</p>
	 * 
	 * @example Here is a code example. 
	 *  
	 * <listing version="3.0">
	 * <p>Describe this code example.</p>
	 *
	 * </listing>
	 *
	 * CLASS VISIBILITY :  INTERNAL : YES, USERS : NO
	 * @private
	 * 
	 */
	public class Preloader extends Sprite implements IPreloader
	{

		// --------------------------------------
		// Properties
		// --------------------------------------
		// PUBLIC GETTER/SETTERS

		// PUBLIC CONST

		// PRIVATE
		/**
		 * The %100 showing of how much is loaded
		 * 
		 */
		private var _textField : TextField;

		// --------------------------------------
		// Constructor
		// --------------------------------------
		/**
		 * This is the constructor.
		 * 
		 */
		public function Preloader()
		{
			// SUPER
			super();

			// EVENTS
			addEventListener(Event.ADDED_TO_STAGE, _onAddedToStage);

			// VARIABLES
      
			// PROPERTIES
      
      
			// METHODS

		}


		// --------------------------------------
		// Methods
		// --------------------------------------
		// PUBLIC
		/**
		 * Show 
		 * 
		 * @return void
		 * 
		 */
		public function show() : void
		{
			visible = true;
		}

		/**
		 * Hide 
		 * 
		 * @return void
		 * 
		 */
		public function hide() : void
		{
			visible = false;
		}

		/**
		 * Destroy 
		 * 
		 * @return void
		 * 
		 */
		public function destroy() : void
		{
			if (this.parent.contains(this)) {
				this.parent.removeChild(this);
			}
		}

		/**
		 * Destroy 
		 * 
		 * @param percentage_uint : uint
		 * 
		 * @return void
		 * 
		 */
		public function update(percentage_num : Number) : void
		{
			_textField.htmlText = "<p align='center'>" + Math.round(percentage_num * 100) + "%</p>";

		}


		// PRIVATE
		/**
		 * Layout 
		 * 
		 * @return void
		 */
		private function _doLayout() : void
		{
			_textField = new TextField();
			var textFormat : TextFormat = _textField.getTextFormat();
			textFormat.size = 10;
			textFormat.color = 0x000000;
			_textField.setTextFormat(textFormat);

			var loaderSprite : Sprite = new PreloaderAssetManager.LoaderMC();
			loaderSprite.x = stage.stageWidth / 2 - loaderSprite.width / 2;
			loaderSprite.y = stage.stageHeight / 2 - loaderSprite.height / 2;
			addChild(loaderSprite);

			//
			_textField.embedFonts = false;
			// use no embeds for a small k-size
			_textField.selectable = false;
			_textField.antiAliasType = AntiAliasType.ADVANCED;
			_textField.width = stage.stageWidth;
			_textField.y = stage.stageHeight / 2 - 7;
			addChild(_textField);
		}

		// --------------------------------------
		// Event Handlers
		// --------------------------------------
		/**
		 * Handles the event: <code>Event.ADDED_TO_STAGE</code>.
		 * 
		 * @param event <code>Event</code> The incoming event payload.
		 *  
		 * @return void
		 * 
		 */
		private function _onAddedToStage(event : Event) : void
		{
			_doLayout();
		}
	}
}